@@ -1,6 +1,7 @@
 library("R.utils")
 
 strings <- list(
+  "",
   "hello world"   = c("helloWorld", "HelloWorld", "helloWorld", "HelloWorld"),
   "tcn start"     = c("tcnStart", "TcnStart", "tcnStart", "TcnStart"),
   "GEO Accession" = c("gEOAccession", "GEOAccession", "geoAccession", "GEOAccession")
@@ -32,10 +33,15 @@ for (s in names(strings)) {
 s <- names(strings)
 y <- toCamelCase(s)
 stopifnot(length(y) == length(s))
-stopifnot(all(y == sapply(strings, FUN=function(s) s[1L])))
+y0 <- sapply(strings, FUN=function(s) s[1L])
+stopifnot(all(y == y0))
 
 # Empty vector
 y <- toCamelCase(character(0L))
 stopifnot(length(y) == 0L)
 y <- toCamelCase(NULL)
 stopifnot(length(y) == 0L)
+
+# Missing values
+y <- toCamelCase(NA_character_)
+stopifnot(is.na(y))
