@@ -7,10 +7,18 @@ mfile <- function(file, ...) {
   mcat("-------------------------------------------------\n")
 } # mfile()
 
+
+# Display warnings as they occur
+oopts <- options(warn=1L)
+
+# Clear all warnings
+resetWarnings()
+
 cons0 <- showConnections()
 
 # Divert standard output
 pathname <- tempfile(fileext=".output.txt")
+mprint(pathname)
 res <- withSink(file=pathname, {
   print(letters)
   NULL
@@ -21,6 +29,7 @@ mprint(warnings())
 
 # Divert standard error/messages
 pathname <- tempfile(fileext=".message.txt")
+mprint(pathname)
 res <- withSink(file=pathname, type="message", {
   mprint(letters)
   NULL
@@ -31,6 +40,7 @@ mprint(warnings())
 
 # Divert standard output (and make sure to close any other sinks opened)
 pathname <- tempfile(fileext=".output2.txt")
+mprint(pathname)
 res <- withSink(file=pathname, {
   print(letters)
   pathnameT <- tempfile(fileext=".output3.txt")
@@ -40,9 +50,37 @@ res <- withSink(file=pathname, {
 }, append=TRUE)
 mfile(pathname)
 mprint(warnings())
+resetWarnings()
+
 
 # Assert that all connections opened were closed
 cons1 <- showConnections()
 mprint(cons0)
 mprint(cons1)
 stopifnot(all.equal(cons1, cons0))
+
+# Reset how warnings are displayed and clear any generated
+options(oopts)
+resetWarnings()
+
+
+
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+# Visibility
+# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+pathname <- tempfile(fileext=".output.txt")
+res <- withVisible({
+  withSink({ print(1); 1 }, file=pathname)
+})
+str(res)
+stopifnot(all.equal(res$value, 1))
+stopifnot(res$visible)
+
+x <- 0
+res <- withVisible({
+  withSink({ print(1); x <- 1 }, file=pathname)
+})
+str(res)
+stopifnot(all.equal(res$value, 1))
+stopifnot(!res$visible)
+stopifnot(all.equal(x, 1))
